@@ -11,7 +11,7 @@ def _make_dirs_if_not_exists(persist_dir):
         os.makedirs(persist_dir)
 
 def _write_old_dict(input, persist_dir):
-    _make_dirs_if_not_exists(persist_dir)
+    _make_dirs_if_not_exists(os.path.expanduser(persist_dir))
     with open(_old_dict_filename(persist_dir), 'w+') as f:
         f.write(str(input))
 
